@@ -1238,7 +1238,7 @@ extern "C" PyObject *method_keyword_call_handler( PyObject *_self_and_name_tuple
 		PyObject *self_in_cobject = self_and_name_tuple[0].ptr();
 		void *self_as_void = PyCObject_AsVoidPtr( self_in_cobject );
 		if( self_as_void == NULL )
-		return NULL;
+			return NULL;
 
 		ExtensionModuleBase *self = static_cast<ExtensionModuleBase *>( self_as_void );
 
@@ -1253,13 +1253,11 @@ extern "C" PyObject *method_keyword_call_handler( PyObject *_self_and_name_tuple
 			Object result( self->invoke_method_keyword( name, args, keywords ) );
 			return new_reference_to( result.ptr() );
 			}
-		else
-			{
-			Dict keywords( _keywords );
 
-			Object result( self->invoke_method_keyword( name, args, keywords ) );
-			return new_reference_to( result.ptr() );
-			}
+		Dict keywords( _keywords );
+
+		Object result( self->invoke_method_keyword( name, args, keywords ) );
+		return new_reference_to( result.ptr() );
 		}
 	catch( Exception & )
 		{
