@@ -1,6 +1,6 @@
 //
 // ====================================================================
-// Copyright (c) 2003-2005 Barry A Scott.  All rights reserved.
+// Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
 //
 // This software is licensed as described in the file LICENSE.txt,
 // which you should have received as part of this distribution.
@@ -59,6 +59,9 @@ public:    // data
     //
     Py::Object m_pyfn_GetLogin;
     Py::Object m_pyfn_Notify;
+#ifdef PYSVN_HAS_CONTEXT_PROGRESS
+    Py::Object m_pyfn_Progress;
+#endif
     Py::Object m_pyfn_Cancel;
     Py::Object m_pyfn_GetLogMessage;
     Py::Object m_pyfn_SslServerPrompt;
@@ -105,6 +108,14 @@ private:// methods
         );
 #endif
 
+#ifdef PYSVN_HAS_CONTEXT_PROGRESS
+    void contextProgress
+        (
+        apr_off_t progress,
+        apr_off_t total
+        );
+#endif
+
     //
     // this method will be called periodically to allow
     // the app to cancel long running operations
@@ -180,6 +191,7 @@ public:
     Py::Object cmd_checkin( const Py::Tuple& args, const Py::Dict &kws );
     Py::Object cmd_copy( const Py::Tuple& args, const Py::Dict &kws );
     Py::Object cmd_diff( const Py::Tuple& args, const Py::Dict &kws );
+    Py::Object cmd_diff_peg( const Py::Tuple& args, const Py::Dict &kws );
     Py::Object cmd_export( const Py::Tuple& args, const Py::Dict &kws );
     Py::Object cmd_info( const Py::Tuple& args, const Py::Dict &kws );
 #ifdef PYSVN_HAS_CLIENT_INFO
@@ -192,6 +204,7 @@ public:
 #endif
     Py::Object cmd_ls( const Py::Tuple& args, const Py::Dict &kws );
     Py::Object cmd_merge( const Py::Tuple& args, const Py::Dict &kws );
+    Py::Object cmd_merge_peg( const Py::Tuple& args, const Py::Dict &kws );
     Py::Object cmd_mkdir( const Py::Tuple& args, const Py::Dict &kws );
     Py::Object cmd_move( const Py::Tuple& args, const Py::Dict &kws );
     Py::Object cmd_propdel( const Py::Tuple& args, const Py::Dict &kws );
@@ -234,10 +247,10 @@ private:
 class pysvn_transaction : public Py::PythonExtension<pysvn_transaction>
 {
 public:
-    pysvn_transaction( pysvn_module &module,
-        const std::string &repos_path,
-        const std::string &transaction_name );
+    pysvn_transaction( pysvn_module &module );
     virtual ~pysvn_transaction();
+    void init( const std::string &repos_path,
+        const std::string &transaction_name );
 
     // override functions from PythonExtension
     virtual Py::Object getattr( const char *name );
@@ -282,6 +295,7 @@ public:
 
     virtual Py::Object getattr( const char *name );
     virtual int setattr( const char *name, const Py::Object &value );
+    virtual Py::Object pysvn_revision::repr();
 
     const svn_opt_revision_t &getSvnRevision() const;
 
@@ -352,12 +366,15 @@ public:
 
     bool getBoolean( const char *name );
     bool getBoolean( const char *name, bool default_value );
+    int getInteger( const char *name );
+    int getInteger( const char *name, int default_value );
     std::string getUtf8String( const char *name );
     std::string getUtf8String( const char *name, const std::string &default_value );
     std::string getString( const char *name, const std::string &default_value );
     std::string getString( const char *name );
     svn_opt_revision_t getRevision( const char *name );
     svn_opt_revision_t getRevision( const char *name, svn_opt_revision_kind default_value );
+    svn_opt_revision_t getRevision( const char *name, svn_opt_revision_t default_value );
 
 private:
     const std::string           m_function_name;
@@ -653,11 +670,15 @@ extern Py::Object path_string_or_none( const char *str, SvnPool &pool );
 extern Py::Object utf8_string_or_none( const std::string &str );
 extern apr_time_t convertStringToTime( const std::string &text, apr_time_t now, SvnPool &pool );
 extern Py::Object toObject( apr_time_t t );
-extern Py::Object toObject( svn_client_commit_info_t *commit_info );
+extern Py::Object toObject( pysvn_commit_info_t *commit_info );
 #ifdef PYSVN_HAS_CLIENT_INFO
 extern Py::Object toObject( const svn_info_t *info );
 #endif
+#ifdef PYSVN_HAS_CLIENT_LOCK
+extern Py::Object toObject( const svn_lock_t *lock );
+#endif
 extern Py::Object propsToObject( apr_hash_t *props, SvnPool &pool );
+extern Py::Object revnumListToObject( apr_array_header_t *revs, SvnPool &pool );
 extern void proplistToObject( Py::List &py_path_propmap_list, apr_array_header_t *props, SvnPool &pool );
 extern Py::String asUtf8String( Py::Object obj );
 extern apr_array_header_t *targetsFromStringOrList( Py::Object arg, SvnPool &pool );
