@@ -1,6 +1,6 @@
 //
 // ====================================================================
-// Copyright (c) 2003-2005 Barry A Scott.  All rights reserved.
+// Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
 //
 // This software is licensed as described in the file LICENSE.txt,
 // which you should have received as part of this distribution.
@@ -24,6 +24,9 @@ pysvn_context::pysvn_context( const std::string &config_dir )
 : SvnContext( config_dir )
 , m_pyfn_GetLogin()
 , m_pyfn_Notify()
+#ifdef PYSVN_HAS_CONTEXT_PROGRESS
+, m_pyfn_Progress()
+#endif
 , m_pyfn_GetLogMessage()
 , m_pyfn_SslServerPrompt()
 , m_pyfn_SslServerTrustPrompt()
@@ -138,6 +141,42 @@ bool pysvn_context::contextGetLogin
     return false;
 }
 
+#ifdef PYSVN_HAS_CONTEXT_PROGRESS
+void pysvn_context::contextProgress
+    (
+    apr_off_t progress,
+    apr_off_t total
+    )
+{
+    PythonDisallowThreads callback_permission( m_permission );
+
+    // make sure we can call the users object
+    if( !m_pyfn_Progress.isCallable() )
+        return;
+
+    Py::Callable callback( m_pyfn_Progress );
+
+    Py::Tuple args( 2 );
+    // on some platforms apr_off_t is int64
+    args[0] = Py::Int( static_cast<long int>( progress ) );
+    args[1] = Py::Int( static_cast<long int>( total ) );
+
+    Py::Object results;
+
+    try
+    {
+        results = callback.apply( args );
+    }
+    catch( Py::Exception &e )
+    {
+        PyErr_Print();
+        e.clear();
+
+        m_error_message = "unhandled exception in callback_progress";
+    }
+}
+#endif
+
 // 
 // this method will be called to notify about
 // the progress of an ongoing action
@@ -172,6 +211,15 @@ void pysvn_context::contextNotify2
     info["content_state"] = toEnumValue( notify->content_state );
     info["prop_state"] = toEnumValue( notify->prop_state );
     info["revision"] = Py::asObject( new pysvn_revision( svn_opt_revision_number, 0, notify->revision ) );
+    if( notify->err != NULL )
+    {
+        SvnException error( notify->err );
+        info["error"] = error.pythonExceptionArg( 1 );
+    }
+    else
+    {
+        info["error"] = Py::None();
+    }
 
     Py::Object results;
 
