@@ -1,6 +1,6 @@
 //
 // ====================================================================
-// Copyright (c) 2003-2005 Barry A Scott.  All rights reserved.
+// Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
 //
 // This software is licensed as described in the file LICENSE.txt,
 // which you should have received as part of this distribution.
@@ -98,13 +98,23 @@ Py::Object toObject( apr_time_t t )
     return Py::Float( double( t )/1000000 );
 }
 
-Py::Object toObject( svn_client_commit_info_t *commit_info )
+#if defined( PYSVN_HAS_SVN_COMMIT_INFO_T )
+Py::Object toObject( pysvn_commit_info_t *commit_info )
 {
     if( commit_info == NULL || !SVN_IS_VALID_REVNUM( commit_info->revision ) )
         return Py::Nothing();
 
     return Py::asObject( new pysvn_revision( svn_opt_revision_number, 0, commit_info->revision ) );
 }
+#else
+Py::Object toObject( pysvn_commit_info_t *commit_info )
+{
+    if( commit_info == NULL || !SVN_IS_VALID_REVNUM( commit_info->revision ) )
+        return Py::Nothing();
+
+    return Py::asObject( new pysvn_revision( svn_opt_revision_number, 0, commit_info->revision ) );
+}
+#endif
 
 #ifdef PYSVN_HAS_CLIENT_INFO
 Py::Object toObject( const svn_info_t *info )
@@ -144,22 +154,7 @@ Py::Object toObject( const svn_info_t *info )
     }
     else
     {
-        Py::Dict py_lock;
-        py_lock[str_path] = utf8_string_or_none( info->lock->path );
-        py_lock[str_token] = utf8_string_or_none( info->lock->token );
-        py_lock[str_owner] = utf8_string_or_none( info->lock->owner );
-        py_lock[str_comment] = utf8_string_or_none( info->lock->comment );
-        py_lock[str_is_dav_comment] = Py::Int( info->lock->is_dav_comment != 0 );
-        if( info->lock->creation_date == 0 )
-            py_lock[str_creation_date] = Py::None();
-        else
-            py_lock[str_creation_date] = toObject( info->lock->creation_date );
-        if( info->lock->expiration_date == 0 )
-            py_lock[str_expiration_date] = Py::None();
-        else
-            py_lock[str_expiration_date] = toObject( info->lock->expiration_date );
-
-        py_info[str_lock] = py_lock;
+        py_info[str_lock] = toObject( info->lock );
     }
 
     // Whether or not to ignore the next 10 wc-specific fields.
@@ -186,6 +181,27 @@ Py::Object toObject( const svn_info_t *info )
     return py_info;
 }
 #endif
+#ifdef PYSVN_HAS_CLIENT_LOCK
+Py::Object toObject( const svn_lock_t *lock )
+{
+    Py::Dict py_lock;
+    py_lock[str_path] = utf8_string_or_none( lock->path );
+    py_lock[str_token] = utf8_string_or_none( lock->token );
+    py_lock[str_owner] = utf8_string_or_none( lock->owner );
+    py_lock[str_comment] = utf8_string_or_none( lock->comment );
+    py_lock[str_is_dav_comment] = Py::Int( lock->is_dav_comment != 0 );
+    if( lock->creation_date == 0 )
+        py_lock[str_creation_date] = Py::None();
+    else
+        py_lock[str_creation_date] = toObject( lock->creation_date );
+    if( lock->expiration_date == 0 )
+        py_lock[str_expiration_date] = Py::None();
+    else
+        py_lock[str_expiration_date] = toObject( lock->expiration_date );
+
+    return py_lock;
+}
+#endif
 
 Py::Object propsToObject( apr_hash_t *props, SvnPool &pool )
 {
@@ -223,6 +239,22 @@ void proplistToObject( Py::List &py_path_propmap_list, apr_array_header_t *props
     }
 }
 
+Py::Object revnumListToObject( apr_array_header_t *revs, SvnPool &pool )
+{
+    Py::List py_list;
+
+    for (int j = 0; j < revs->nelts; ++j)
+    {
+        svn_revnum_t revnum = ((svn_revnum_t *)revs->elts)[j];
+
+        Py::Object py_rev( Py::asObject( new pysvn_revision( svn_opt_revision_number, 0, revnum ) ) );
+
+        py_list.append( py_rev );
+    }
+
+    return py_list;
+}
+
 Py::String asUtf8String( Py::Object obj )
 {
     Py::String any( obj );
