@@ -1,6 +1,6 @@
 //
 // ====================================================================
-// Copyright (c) 2003-2005 Barry A Scott.  All rights reserved.
+// Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
 //
 // This software is licensed as described in the file LICENSE.txt,
 // which you should have received as part of this distribution.
@@ -99,14 +99,19 @@ Py::Object &SvnException::pythonExceptionArg( int style )
 //--------------------------------------------------------------------------------
 SvnContext::SvnContext( const std::string &config_dir_str )
 : m_pool( NULL )
+, m_config_dir( NULL )
 {
+    memset( &m_context, 0, sizeof( m_context ) );
+
     apr_pool_create( &m_pool, NULL );
 
-    const char *config_dir = NULL;
     if( !config_dir_str.empty() )
-        config_dir = config_dir_str.c_str();
+    {
+        m_config_dir = new char[config_dir_str.size() + 1];
+        strcpy( m_config_dir, config_dir_str.c_str() );
+    }
 
-    svn_config_ensure( config_dir, m_pool );
+    svn_config_ensure( m_config_dir, m_pool );
 
     apr_array_header_t *providers = apr_array_make( m_pool, 8, sizeof( svn_auth_provider_object_t * ) );
 
@@ -143,16 +148,25 @@ SvnContext::SvnContext( const std::string &config_dir_str )
     svn_auth_open( &auth_baton, providers, m_pool );
 
     // get the config based on the config dir passed in
-    svn_config_get_config( &m_context.config, config_dir, m_pool );
+    svn_config_get_config( &m_context.config, m_config_dir, m_pool );
 
     // tell the auth functions where the config dir is
-    svn_auth_set_parameter( auth_baton, SVN_AUTH_PARAM_CONFIG_DIR, config_dir );
+    svn_auth_set_parameter( auth_baton, SVN_AUTH_PARAM_CONFIG_DIR, m_config_dir );
 
     m_context.auth_baton = auth_baton;
+#ifdef PYSVN_HAS_CONTEXT_LOG_MSG2
+    m_context.log_msg_func2 = handlerLogMsg2;
+    m_context.log_msg_baton2 = this;
+    m_context.log_msg_func = NULL;
+    m_context.log_msg_baton = NULL;
+#else
     m_context.log_msg_func = handlerLogMsg;
     m_context.log_msg_baton = this;
+#endif
+
     m_context.cancel_func = handlerCancel;
     m_context.cancel_baton = this;
+
 #ifdef PYSVN_HAS_CONTEXT_NOTIFY2
     m_context.notify_func2 = handlerNotify2;
     m_context.notify_baton2 = this;
@@ -162,10 +176,18 @@ SvnContext::SvnContext( const std::string &config_dir_str )
     m_context.notify_func = handlerNotify;
     m_context.notify_baton = this;
 #endif
+
+#ifdef PYSVN_HAS_CONTEXT_PROGRESS
+    m_context.progress_func = handlerProgress;
+    m_context.progress_baton = this;
+#endif
+
 }
 
 SvnContext::~SvnContext()
 {
+    delete m_config_dir;
+
 // Why isn't the pool release - object life time problems?
 //    if( m_pool )
 //    {
@@ -183,6 +205,29 @@ svn_client_ctx_t *SvnContext::ctx()
     return &m_context;
 }
 
+#ifdef PYSVN_HAS_CONTEXT_LOG_MSG2
+svn_error_t *SvnContext::handlerLogMsg2
+    (
+    const char **log_msg,
+    const char **tmp_file,
+    const apr_array_header_t *commit_items,
+    void *baton,
+    apr_pool_t *pool
+    )
+{
+    SvnContext *context = reinterpret_cast<SvnContext *>( baton );
+
+    std::string msg;
+
+    if (!context->contextGetLogMessage( msg ) )
+        return svn_error_create( SVN_ERR_CANCELLED, NULL, "" );
+
+    *log_msg = svn_string_ncreate( msg.data(), msg.length(), pool )->data;
+    *tmp_file = NULL;
+
+    return SVN_NO_ERROR;
+}
+#else
 svn_error_t *SvnContext::handlerLogMsg
     (
     const char **log_msg,
@@ -204,6 +249,7 @@ svn_error_t *SvnContext::handlerLogMsg
 
     return SVN_NO_ERROR;
 }
+#endif
 
 #ifdef PYSVN_HAS_CONTEXT_NOTIFY2
 void SvnContext::handlerNotify2
@@ -236,6 +282,21 @@ void SvnContext::handlerNotify
 }
 #endif
 
+#ifdef PYSVN_HAS_CONTEXT_PROGRESS
+void SvnContext::handlerProgress
+    (
+    apr_off_t progress,
+    apr_off_t total,
+    void *baton,
+    apr_pool_t *pool
+    )
+{
+    SvnContext *context = reinterpret_cast<SvnContext *>( baton );
+
+    context->contextProgress( progress, total );
+}
+#endif
+
 svn_error_t *SvnContext::handlerCancel
     (
     void * baton
